// automatically generated by admSerialization.py, do not edit!
// automatically generated by admSerialization.py do not edit
#ifndef ADM_FFcodecSettings_CONF_H
#define ADM_FFcodecSettings_CONF_H
typedef struct {
COMPRES_PARAMS params;
FFcodecContext lavcSettings;
}FFcodecSettings;
#endif
