/**
    \file ADM_audioCodecEnum.h
*/
#ifndef ADM_audioCodecEnum_H
#define ADM_audioCodecEnum_H

#define WAV_MP3 	85
#define WAV_MP2 	80
#define WAV_WMA 	353
#define WAV_WMAPRO 	354
#define WAV_WMALOSSLESS 0x163
#define WAV_PCM 	1
#define WAV_MSADPCM 	2
#define WAV_LPCM 	3
#define WAV_AC3 	0x2000
#define WAV_DTS 	0x2001
#define WAV_EAC3 	0x2002 // dummy
#define WAV_PCM_FLOAT   0x2003 // dummy, internal format used by avidemux
#define WAV_OGG_VORBIS  0x676f
#define WAV_OPUS        9902 
#define WAV_8BITS 	53 // dummy id
#define WAV_MP4 	54 // dummy id
#define WAV_AAC 	0xff // dummy id
#define WAV_AAC_HE 	0xfe // dummy id
#define WAV_8BITS_UNSIGNED 	55 // dummy id
#define WAV_AMRNB 	56 // dummy id
#define WAV_AMRWB 	57 // dummy id
#define WAV_ALAW        6
#define WAV_ULAW	7 
#define WAV_QDM2 	58
#define WAV_IMAADPCM    17
#define WAV_AMV_ADPCM    9900
#define WAV_NELLYMOSER   9901
#define WAV_UNKNOWN     9999
#define WAV_FLAC        61868 // dummy ID
#define WAV_TRUEHD      0x5254 // 0x44485254

#endif
//EOF
